@@ -631,11 +631,26 @@ void AppleK2::saveK2State(void)
     savedK2MPICState->mpicSpuriousVector = *(UInt32 *)(mpicBaseAddr + kKeyLargoMPICSpuriousVector);
     savedK2MPICState->mpicTimerFrequencyReporting = *(UInt32 *)(mpicBaseAddr + kKeyLargoMPICTimeFreq);
 
-    savedK2MPICState->mpicTimers[0] = *(MPICTimers *)(mpicBaseAddr + kKeyLargoMPICTimerBase0);
-    savedK2MPICState->mpicTimers[1] = *(MPICTimers *)(mpicBaseAddr + kKeyLargoMPICTimerBase1);
-    savedK2MPICState->mpicTimers[2] = *(MPICTimers *)(mpicBaseAddr + kKeyLargoMPICTimerBase2);
-    savedK2MPICState->mpicTimers[3] = *(MPICTimers *)(mpicBaseAddr + kKeyLargoMPICTimerBase3);
-
+    // [4101414] timer registers in KeyLargo are on 16byte boundaries
+    UInt32 timerAddresses[kKeyLargoMPICTimerCount] = {kKeyLargoMPICTimerBase0,
+                                                      kKeyLargoMPICTimerBase1,
+                                                      kKeyLargoMPICTimerBase2,
+                                                      kKeyLargoMPICTimerBase3};
+    UInt32 *MPICRegPtr;
+    MPICTimers *SavedMPICReg;
+    
+    for (i = 0; i < kKeyLargoMPICTimerCount; i++)
+    {
+        SavedMPICReg = &savedK2MPICState->mpicTimers[i];
+        MPICRegPtr = (UInt32 *)(mpicBaseAddr + timerAddresses[i] - 0x10);   
+        // ???BaseX - 0x10 == CurrentCountRegister
+        
+        SavedMPICReg->currentCountRegister = *(MPICRegPtr + 0);
+        SavedMPICReg->baseCountRegister = *(MPICRegPtr + 0x4);
+        SavedMPICReg->vectorPriorityRegister = *(MPICRegPtr + 0x8);
+        SavedMPICReg->destinationRegister = *(MPICRegPtr + 0xc);
+    }
+	
     for (i = 0; i < kKeyLargoMPICVectorsCount; i++)
     {
         // Make sure that the "active" bit is cleared.
@@ -694,14 +709,25 @@ void AppleK2::restoreK2State(void)
     *(UInt32 *)(mpicBaseAddr + kKeyLargoMPICTimeFreq) = savedK2MPICState->mpicTimerFrequencyReporting;
     eieio();
 
-    *(MPICTimers *)(mpicBaseAddr + kKeyLargoMPICTimerBase0) = savedK2MPICState->mpicTimers[0];
-    eieio();
-    *(MPICTimers *)(mpicBaseAddr + kKeyLargoMPICTimerBase1) = savedK2MPICState->mpicTimers[1];
-    eieio();
-    *(MPICTimers *)(mpicBaseAddr + kKeyLargoMPICTimerBase2) = savedK2MPICState->mpicTimers[2];
-    eieio();
-    *(MPICTimers *)(mpicBaseAddr + kKeyLargoMPICTimerBase3) = savedK2MPICState->mpicTimers[3];
-    eieio();
+    // [4101414] timer registers in KeyLargo are on 16byte boundaries
+    UInt32 timerAddresses[kKeyLargoMPICTimerCount] = {kKeyLargoMPICTimerBase0,
+                     			             kKeyLargoMPICTimerBase1,
+                     			             kKeyLargoMPICTimerBase2,
+                     			             kKeyLargoMPICTimerBase3};
+    UInt32 *MPICRegPtr;
+    MPICTimers *savedMPICReg;
+    
+    for (i = 0; i < kKeyLargoMPICTimerCount; i++)
+    {
+        savedMPICReg = &savedK2MPICState->mpicTimers[i];
+        MPICRegPtr = (UInt32 *)(mpicBaseAddr + timerAddresses[i] - 0x10);   
+        // ???BaseX - 0x10 == CurrentCountRegister
+        
+         *(MPICRegPtr + 0x0) = savedMPICReg->currentCountRegister;   eieio();
+         *(MPICRegPtr + 0x4) = savedMPICReg->baseCountRegister;     eieio();
+         *(MPICRegPtr + 0x8) = savedMPICReg->vectorPriorityRegister;    eieio();
+         *(MPICRegPtr + 0xc) = savedMPICReg->destinationRegister;   eieio();
+    }
 
     for (i = 0; i < kKeyLargoMPICVectorsCount; i++)
     {
